@@ -3,7 +3,7 @@ package CracTools::Utils;
   $CracTools::Utils::DIST = 'CracTools';
 }
 # ABSTRACT: A set of useful functions
-$CracTools::Utils::VERSION = '1.24';
+$CracTools::Utils::VERSION = '1.25';
 use strict;
 use warnings;
 
@@ -13,10 +13,10 @@ use Fcntl qw( SEEK_SET );
 
 sub reverseComplement($) {
   my $dna = shift;
-  
+
   # reverse the DNA sequence
   my $revcomp = reverse $dna;
-  
+
   # complement the reversed DNA sequence
   $revcomp =~ tr/ACGTacgt/TGCAtgca/;
   return $revcomp;
@@ -60,12 +60,12 @@ sub isVersionGreaterOrEqual($$) {
 my %conversion_hash = ( '+' => 1, '-' => '-1', '1' => '+', '-1' => '-');
 sub convertStrand($) {
   my $strand = shift;
-  return $conversion_hash{$strand};
+  return defined $strand? $conversion_hash{$strand} : undef;
 }
 
 sub removeChrPrefix($) {
   my $string = shift;
-  $string =~ s/^chr//;
+  $string =~ s/^chr//i;
   return $string;
 }
 
@@ -81,7 +81,7 @@ our @Base64_ENCODING = qw(A B C D E F G H I J K L M N O P Q R S T U V W X Y Z a
 # Encode error list into base64
 sub encodePosListToBase64 {
   my @pos_list = @_;
-  my @bitList; 
+  my @bitList;
   my $encoded_str;
 
   return "" if @pos_list == 0;
@@ -102,10 +102,10 @@ sub encodePosListToBase64 {
   foreach my $j (@pos_list) {
     $bitList[int($j / $Base64_BITNESS)] |= (1 << ($j % $Base64_BITNESS));
   }
-  
+
   # Convert bitList into string_Base64_ENCODING
   for(my $k=0; $k < $bitList_length; $k++) {
-    $encoded_str .= scalar($Base64_ENCODING[$bitList[$k]]); 
+    $encoded_str .= scalar($Base64_ENCODING[$bitList[$k]]);
   }
   return $encoded_str;
 }
@@ -124,7 +124,7 @@ sub decodePosListInBase64 {
     push(@index,$ind[0]);
   }
 
-  # Convert into list position     
+  # Convert into list position
   for (my $e = 0; $e < (0+@encoded_list);$e++) {
     for(my $i=0; $i<$Base64_BITNESS; $i++) {
       if ($index[$e] & (1 << $i)) {
@@ -132,9 +132,9 @@ sub decodePosListInBase64 {
         push(@decoded_list,$pos);
       }
     }
-  }  
+  }
 
-  return @decoded_list; 
+  return @decoded_list;
 }
 
 
@@ -168,7 +168,7 @@ sub seqFileIterator {
     my $prev_line = <$fh>;
     chomp $prev_line;
     return sub {
-      my ($name,$seq,$qual); 
+      my ($name,$seq,$qual);
       if(defined $prev_line) {
         ($name) = $prev_line =~ />(.*)$/;
         $prev_line = <$fh>;
@@ -187,7 +187,7 @@ sub seqFileIterator {
   # FASTQ ITERATOR
   } elsif ($format eq 'fastq') {
     return sub {
-      my ($name,$seq,$qual); 
+      my ($name,$seq,$qual);
       my $line = <$fh>;
       ($name) = $line =~ /@(.*)$/ if defined $line;
       if(defined $name) {
@@ -272,8 +272,8 @@ sub bamFileIterator {
   }
 
   return sub {
-    return <$fh>; 
-  } 
+    return <$fh>;
+  }
 
 }
 
@@ -310,8 +310,8 @@ sub parseBedLine {
     my @block_starts = split(",",$block_starts);
     my $cumulated_block_size = 0;
     for(my $i = 0; $i < $block_count; $i++) {
-      push(@blocks,{size        => $block_size[$i], 
-                   start        => $block_starts[$i], 
+      push(@blocks,{size        => $block_size[$i],
+                   start        => $block_starts[$i],
                    end          => $block_starts[$i] + $block_size[$i],
                    block_start  => $cumulated_block_size,
                    block_end    => $cumulated_block_size + $block_size[$i],
@@ -323,10 +323,10 @@ sub parseBedLine {
   }
 
   return { chr        => $chr,
-    start       => $start, 
-    end         => $end, 
+    start       => $start,
+    end         => $end,
     name        => $name,
-    score       => $score, 
+    score       => $score,
     strand      => $strand,
     thick_start => $thick_start,
     thick_end   => $thick_end,
@@ -356,10 +356,10 @@ sub parseGFFLine {
   }
   return { chr        => $chr,
     source     => $source,
-    feature    => $feature, 
-    start      => $start, 
-    end        => $end, 
-    score      => $score, 
+    feature    => $feature,
+    start      => $start,
+    end        => $end,
+    score      => $score,
     strand     => $strand,
     frame      => $frame,
     attributes => \%attributes_hash,
@@ -370,13 +370,10 @@ sub parseGFFLine {
 sub parseVCFLine {
   my $line = shift;
   my($chr,$pos,$id,$ref,$alt,$qual,$filter,$info) = split("\t",$line);
-  my @alts = split(",",$alt);
-  my %infos;
-  my @infos = split(";",$info);
-  foreach (@infos) {
-    my($k,$v) = split("=",$_);
-    $infos{$k} = $v;
-  }
+
+  my @alts = defined $alt? split(",",$alt) : ();
+  my %infos = defined $info?
+  map { my ($k,$v) = split '='; $k => $v } split ';', $info : ();
 
   return { chr => $chr,
     pos     => $pos,
@@ -390,41 +387,41 @@ sub parseVCFLine {
 }
 
 
-sub parseChimCTLine {                                                     
-  my $line = shift;                                                       
+sub parseChimCTLine {
+  my $line = shift;
   my($id,$name,$chr1,$pos1,$strand1,$chr2,$pos2,$strand2,$chim_value,$spanning_junction,$spanning_PE,$class,$comments,@others) = split("\t",$line);
-  my($sample,$chim_key) = split(":",$id);                                 
-  my @comments = split(",",$comments);                                    
-  my %comments;                                                           
-  foreach my $com (@comments){                                            
-      my ($key,$val) = split("=",$com);                                   
-      $comments{$key} = $val;                                             
-  }                                                                       
-  my %extend_fields;                                                      
-  foreach my $field (@others) {                                           
-    my ($key,$val) = split("=",$field);                                   
-    if(defined $key && defined $val) {                                    
-      $extend_fields{$key} = $val;                                        
-    }                                                                     
-  }                                                                       
-  return {                                                                
-    sample            => $sample,                                                    
+  my($sample,$chim_key) = split(":",$id);
+  my @comments = split(",",$comments);
+  my %comments;
+  foreach my $com (@comments){
+      my ($key,$val) = split("=",$com);
+      $comments{$key} = $val;
+  }
+  my %extend_fields;
+  foreach my $field (@others) {
+    my ($key,$val) = split("=",$field);
+    if(defined $key && defined $val) {
+      $extend_fields{$key} = $val;
+    }
+  }
+  return {
+    sample            => $sample,
     chim_key          => $chim_key,
     name              => $name,
-    chr1              => $chr1,                                                        
-    pos1              => $pos1,                                                        
-    strand1           => $strand1,                                                  
-    chr2              => $chr2,                                                        
-    pos2              => $pos2,                                                        
-    strand2           => $strand2,                                                  
-    chim_value        => $chim_value,                                            
-    spanning_junction => $spanning_junction,                              
-    spanning_PE       => $spanning_PE,                                          
-    class             => $class,                                                      
-    comments          => \%comments,                                               
-    extended_fields     => \%extend_fields,                                     
-  };                                                                      
-} 
+    chr1              => $chr1,
+    pos1              => $pos1,
+    strand1           => $strand1,
+    chr2              => $chr2,
+    pos2              => $pos2,
+    strand2           => $strand2,
+    chim_value        => $chim_value,
+    spanning_junction => $spanning_junction,
+    spanning_PE       => $spanning_PE,
+    class             => $class,
+    comments          => \%comments,
+    extended_fields     => \%extend_fields,
+  };
+}
 
 
 sub parseSAMLineLite {
@@ -478,7 +475,7 @@ sub getFileIterator {
       $parsing_method = sub { return parseGFFLine(@_,$type) };
       push (@parsing_arguments,$type);
     } elsif($type =~ /bed/i) {
-      $header_regex = '^track\s';
+      $header_regex = '(^track\s)|(^#)';
       $parsing_method = \&parseBedLine;
     } elsif ($type =~ /vcf/i) {
       $header_regex = '^#';
@@ -514,7 +511,7 @@ sub getFileIterator {
       $line = <$fh>;
     }
   }
-  
+
   # Skip line that match a specific regex
   if(defined $header_regex) {
     while($line && $line =~ /$header_regex/) {
@@ -588,7 +585,7 @@ CracTools::Utils - A set of useful functions
 
 =head1 VERSION
 
-version 1.24
+version 1.25
 
 =head1 SYNOPSIS
 
@@ -771,7 +768,7 @@ pairedEndSeqFileIterator has no equivalent in Bio-Perl
 
 Write the sequence in the output stream with the specified format.
 
-=head2 bedFileIterator 
+=head2 bedFileIterator
 
 manage BED files format
 
@@ -803,7 +800,7 @@ Return a hashref with the annotation parsed:
     seek_pos    => 'Seek position of this line in the file',
   }
 
-=head2 gffFileIterator 
+=head2 gffFileIterator
 
 manage GFF3 and GTF2 file format
 
@@ -832,7 +829,7 @@ Return a hashref with the annotation parsed:
 
 gffFileIterator is B<5x faster than Bio-Perl> Bio::Tools::GFF
 
-=head2 vcfFileIterator 
+=head2 vcfFileIterator
 
 manage VCF file format
 
@@ -856,19 +853,19 @@ Return a hashref with the annotation parsed:
 Return a hashref with the chimera parsed:
 
   {
-    sample            => $sample,                                                    
-    chim_key          => $chim_key,                                                
+    sample            => $sample,
+    chim_key          => $chim_key,
     name              => $name,
-    chr1              => $chr1,                                                        
-    pos1              => $pos1,                                                        
-    strand1           => $strand1,                                                  
-    chr2              => $chr2,                                                        
-    pos2              => $pos2,                                                        
-    strand2           => $strand2,                                                  
-    chim_value        => $chim_value,                                            
-    spanning_junction => $spanning_junction,                              
-    spanning_PE       => $spanning_PE,                                          
-    class             => $class,                                                      
+    chr1              => $chr1,
+    pos1              => $pos1,
+    strand1           => $strand1,
+    chr2              => $chr2,
+    pos2              => $pos2,
+    strand2           => $strand2,
+    chim_value        => $chim_value,
+    spanning_junction => $spanning_junction,
+    spanning_PE       => $spanning_PE,
+    class             => $class,
     comments          => { coment_id => 'comment_value', ... },
     extended_fields     => { extended_field_id => 'extended_field_value', ... },
   }
@@ -917,7 +914,7 @@ Example:
 
 =head2 parseCigarChain
 
-Given a CIGAR chain (see SAM specification), return a parsed version as an Array ref of 
+Given a CIGAR chain (see SAM specification), return a parsed version as an Array ref of
 cigar elements represented as { nb => 10, op => 'M' }.
 
 =head1 FILES IO
@@ -950,7 +947,7 @@ Example:
   print $fh "Hello world\n";
   close $fh;
 
-=head2 getLineFromSeekPos 
+=head2 getLineFromSeekPos
 
   getLineFromSeekPos($filehandle,$seek_pos);
 
@@ -976,7 +973,7 @@ Sacha BEAUMEUNIER <sacha.beaumeunier@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by IRMB/INSERM (Institute for Regenerative Medecine and Biotherapy / Institut National de la Santé et de la Recherche Médicale) and AxLR/SATT (Lanquedoc Roussilon / Societe d'Acceleration de Transfert de Technologie).
+This software is Copyright (c) 2017 by IRMB/INSERM (Institute for Regenerative Medecine and Biotherapy / Institut National de la Santé et de la Recherche Médicale) and AxLR/SATT (Lanquedoc Roussilon / Societe d'Acceleration de Transfert de Technologie).
 
 This is free software, licensed under:
 
